@@ -135,21 +135,21 @@ class Locale(object):
         'es_UY': {
             'name': 'Español (Uruguay)',
             'locale': 'es_UY.UTF-8',
-            'keymap': 'es',
+            'keymap': 'la-latin1',
             'timezone': 'America/Montevideo',
             'dumpkeys_charset': '',
             'consolefont': 'ter-v14n',
-            'xkblayout': 'es',
+            'xkblayout': 'latam',
             'language': 'es_UY',
         },
         'es_VE': {
             'name': 'Español (Venezuela)',
             'locale': 'es_VE.UTF-8',
-            'keymap': 'es',
+            'keymap': 'la-latin1',
             'timezone': 'America/Caracas',
             'dumpkeys_charset': '',
             'consolefont': 'ter-v14n',
-            'xkblayout': 'es',
+            'xkblayout': 'latam',
             'language': 'es_UY',
         },
         'et_EE': {
@@ -314,7 +314,7 @@ class Locale(object):
         },
         'pt_PT': {
             'name': 'Português (Portugal)',
-            'locale': 'pl_PL.UTF-8@euro',
+            'locale': 'pt_PT.UTF-8@euro',
             'keymap': 'pt-latin9',
             'dumpkeys_charset': '',
             'timezone': 'Europe/Lisbon',
